import { ArgumentParserTree as ArgParseTree } from '../index';

describe('argparse-tree', () => {
	const apRoot = new ArgParseTree( { options: { debug: true, addHelp: true, description: 'argparse-tree example', version: '1.0.0' }, defaults: { debug: true, addHelp: true } } );
	const apNodeC = apRoot.get('a').get('b').get('c');
	const apNodeD = apRoot.get('a').get('b').get('d');
	const apNodeSingle = apRoot.get('single');

	beforeAll(() => {
	});

	afterAll(() => {
	});

	beforeEach(() => {
	});

	afterEach(() => {
	});

	test('Correct command should work', () => {
		const options = apRoot.parser.parseArgs(['a', 'b', 'c']);
		expect(options['subparser_0']).toBe('a');
		expect(options['subparser_1']).toBe('b');
		expect(options['subparser_2']).toBe('c');
	});

	test('Objects are unique', () => {
		expect(apRoot.get('a').get('b').get('c')).toBe(apNodeC);
		expect(apRoot.get('a').get('b').get('d')).toBe(apNodeD);
	});

	test('Level is correct', () => {
		expect(apRoot.get('a').get('b').get('c').level).toBe(3);
	});

	test('path is correct for single node', () => {
		expect(apRoot.get('single').path).toBe('single');
	});

	test('pathArray is correct for single node', () => {
		expect(apRoot.get('single').pathArray).toEqual(['single']);
	});

	test('path is correct', () => {
		expect(apRoot.get('a').get('b').get('c').path).toBe('a/b/c');
	});

	test('pathArray is correct', () => {
		expect(apRoot.get('a').get('b').get('c').pathArray).toEqual(['a', 'b', 'c']);
	});

	test('selectedPath is correct', () => {
		const options = apRoot.parser.parseArgs(['a', 'b', 'c']);
		expect(apRoot.getSelectedPath(options)).toBe('a/b/c');
	});

	test('selectedPathArray is correct', () => {
		const options = apRoot.parser.parseArgs(['a', 'b', 'c']);
		expect(apRoot.getSelectedPathArray(options)).toEqual(['a', 'b', 'c']);
	});

	test('selectedNode is correct', () => {
		{
			const options = apRoot.parser.parseArgs(['a', 'b', 'c']);
			expect(apRoot.getSelectedNode(options)).toBe(apNodeC);
		}
		{
			const options = apRoot.parser.parseArgs(['a', 'b', 'd']);
			expect(apRoot.getSelectedNode(options)).toBe(apNodeD);
		}
	});

	test('Invald command should fail', () => {
		expect(()=>{
			const options = apRoot.parser.parseArgs(['a', 'b', 'XXX']);
		}).toThrow();
	});

});
